@@ -86,7 +86,7 @@ print( "w: ", w)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
 out_Mob = np.zeros( len( v),float);
 pout_Mob = ffi.cast("double *", out_Mob.ctypes.data);
-# w = fm.py_InteractionB( pout_Mob, v, env)
+w = fm.py_InteractionB( pout_Mob, v, env)
 print( "v: ", v)
 print( "w: ", w)
 
@@ -95,7 +95,7 @@ print( "w: ", w)
 v = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
 out_Mob = np.zeros( len( v),float);
 pout_Mob = ffi.cast("double *", out_Mob.ctypes.data);
-# w = fm.py_InteractionMob( pout_Mob, v, env)
+w = fm.py_InteractionMob( pout_Mob, v, env)
 print( "v: ", v)
 print( "w: ", w)
 
@@ -104,7 +104,7 @@ print( "w: ", w)
 v = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
 out_Mob = np.zeros( len( v),float);
 pout_Mob = ffi.cast("double *", out_Mob.ctypes.data);
-# w = fm.py_InteractionBMob( pout_Mob, v, env)
+w = fm.py_InteractionBMob( pout_Mob, v, env)
 print( "v: ", v)
 print( "w: ", w)
 
@@ -130,7 +130,6 @@ num_tup = fm.py_get_num_tuples( env_sparse)
 print( "num_tup: ", num_tup)
 
 
-
 print( "--- py_free_fm_sparse")
 fm.py_free_fm_sparse( env_sparse)
 
