@@ -1,4 +1,4 @@
-import wrapper as pyw
+import pywrapper_fmtools as pyw
 import sys
 
 r=3
@@ -502,8 +502,6 @@ print( "k: ", k)
 print( "Mob: ", Mob)
 print( "nonmodularity indices: ", pnm)
 
-sys.exit()
-
 # Test wrapper for:
 #    int py_IsMeasureBalanced(double* v, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
@@ -845,11 +843,13 @@ print( "v: ", v)
 # Test wrapper for:
 #    int py_sparse_get_tuples(int* tuples, double* v, struct fm_env_sparse* env)
 n = 3
-tuples, v = pyw.sparse_get_tuples( n, env_sparse)
+tuples, v = pyw.sparse_get_tuples( env_sparse)
 print( "n: ", n)
 print( "tuples: ", tuples)
 print( "v: ", v)
 
+sys.exit()
+
 # Test wrapper for:
 #    void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)
 n =3
